@@ -1,5 +1,5 @@
-package Pod::ProjectDocs;
-$Pod::ProjectDocs::VERSION = '0.44';
+package Pod::ProjectDocs 0.45;
+
 use strict;
 use warnings;
 
