@@ -1,5 +1,5 @@
-package Pod::ProjectDocs::ArrowImage;
-$Pod::ProjectDocs::ArrowImage::VERSION = '0.44';
+package Pod::ProjectDocs::ArrowImage 0.45;
+
 use strict;
 use warnings;
 
