@@ -1,5 +1,5 @@
-package Pod::ProjectDocs::CSS;
-$Pod::ProjectDocs::CSS::VERSION = '0.44';
+package Pod::ProjectDocs::CSS 0.45;
+
 use strict;
 use warnings;
 
