@@ -1,5 +1,5 @@
-package Pod::ProjectDocs::Config;
-$Pod::ProjectDocs::Config::VERSION = '0.44';
+package Pod::ProjectDocs::Config 0.45;
+
 use strict;
 use warnings;
 
