@@ -1,5 +1,5 @@
-package Pod::ProjectDocs::Doc;
-$Pod::ProjectDocs::Doc::VERSION = '0.44';
+package Pod::ProjectDocs::Doc 0.45;
+
 use strict;
 use warnings;
 
