@@ -1,5 +1,5 @@
-package Pod::ProjectDocs::DocManager;
-$Pod::ProjectDocs::DocManager::VERSION = '0.44';
+package Pod::ProjectDocs::DocManager 0.45;
+
 use strict;
 use warnings;
 
@@ -111,8 +111,8 @@ sub _croak {
     Carp::croak($msg);
 }
 
-package Pod::ProjectDocs::DocManager::Iterator;
-$Pod::ProjectDocs::DocManager::Iterator::VERSION = '0.44';
+package Pod::ProjectDocs::DocManager::Iterator 0.45;
+
 use base qw/Class::Accessor::Fast/;
 
 __PACKAGE__->mk_accessors(qw/manager index/);
@@ -138,7 +138,7 @@ sub next {
         return $doc;
     }
     else {
-        return undef;
+        return;
     }
 }
 
