@@ -1,5 +1,5 @@
-package Pod::ProjectDocs::File;
-$Pod::ProjectDocs::File::VERSION = '0.44';
+package Pod::ProjectDocs::File 0.45;
+
 use strict;
 use warnings;
 
