@@ -1,5 +1,5 @@
-package Pod::ProjectDocs::IndexPage;
-$Pod::ProjectDocs::IndexPage::VERSION = '0.44';
+package Pod::ProjectDocs::IndexPage 0.45;
+
 use strict;
 use warnings;
 
