@@ -1,5 +1,5 @@
-package Pod::ProjectDocs::Parser;
-$Pod::ProjectDocs::Parser::VERSION = '0.44';
+package Pod::ProjectDocs::Parser 0.45;
+
 use strict;
 use warnings;
 
@@ -109,7 +109,7 @@ sub end_pod {
     # now loop over each para and expand any html escapes or sequences
     $self->_paraExpand( $_ ) foreach (@$ptree);
 
-    $self->{buffer} =~ s/(\n?)<\/pre>\s*<pre>/$1/sg; # concatenate 'pre' blocks
+    $self->{buffer} =~ s/(\n?)<\/pre>\s*<pre>/$1\n/sg; # concatenate 'pre' blocks
     1 while $self->{buffer} =~ s/<pre>(\s+)<\/pre>/$1/sg;
     $self->{buffer} = $self->_makeIndex . $self->{buffer} if $self->{MakeIndex};
     $self->{buffer} =~ s/__POD_PROJECTDOCS_TOP_LINK__/$self->{FirstAnchor}/ge;
@@ -633,18 +633,18 @@ sub gen_html {
     my $mgr_desc   = $args{desc};
     delete $self->{_source_code};
     my $charset = $doc->config->charset || 'UTF-8';
-    open(FILE, "<:encoding($charset)", $doc->origin) or warn $!;
-    while(<FILE>) {
+    open(my $source_fh, "<:encoding($charset)", $doc->origin) or warn $!;
+    while(<$source_fh>) {
         next unless /^\s*sub\s+(\w+)/;
         my $method = $1;
         my $sub = $_;
-        while(<FILE>){
+        while(<$source_fh>){
             $sub .= $_;
             last if /^}/;
         }
         $self->{_source_code}{$method} = $sub;
     }
-    close(FILE);
+    close($source_fh);
     $self->current_files_output_path( $doc->get_output_path );
     $self->_prepare($doc, $components, $mgr_desc);
 #   local $SIG{__WARN__} = sub { };
