@@ -1,5 +1,5 @@
-package Pod::ProjectDocs::Template;
-$Pod::ProjectDocs::Template::VERSION = '0.44';
+package Pod::ProjectDocs::Template 0.45;
+
 use strict;
 use warnings;
 
